/// @file       glcd12864lib.h
/// @copyright  Copyright (c) 2014 Toradex AG
/// @author     $Author: ras$
/// @date       $Date: 2014-03-24 12:00:00 +05:30$
/// @brief      This library allows easy access to the Graphical LCD with Toradex module.
///

#ifndef __GLCD12864LIB_H__
#define __GLCD12864LIB_H__

/// GPIOs used for GLCD
#define GLCD_RW     28          ///<  PWM_B
#define GLCD_RS     30          ///<  PWM_C
#define GLCD_RST    67          ///<  PWM_D
#define GLCD_CS     86          ///<  SSP_FRM
#define GLCD_C86    88          ///<  SSP_SCLK
#define GLCD_LEDA   92          ///<  SSP_TXD
#define GLCD_EN     90          ///<  SSP_RXD

#define GLCD_DATA7  98          ///<  GPIO_98
#define GLCD_DATA6  133         ///<  GPIO_133
#define GLCD_DATA5  103         ///<  GPIO_103
#define GLCD_DATA4  101         ///<  GPIO_101
#define GLCD_DATA3  97          ///<  GPIO_97
#define GLCD_DATA2  85          ///<  GPIO_85
#define GLCD_DATA1  79          ///<  GPIO_79
#define GLCD_DATA0  45          ///<  GPIO_45

#define HIGH        1
#define LOW         0

#define GLCD_COL1   1

#define GLCD_ON     0xAE
#define GLCD_OFF    0xAF

#define GLCD_PAGE1  0xB0
#define GLCD_PAGE2  0xB1
#define GLCD_PAGE3  0xB2
#define GLCD_PAGE4  0xB3
#define GLCD_PAGE5  0xB4
#define GLCD_PAGE6  0xB5
#define GLCD_PAGE7  0xB6
#define GLCD_PAGE8  0xB7

#define USDELAY 10

//******************************************************************************
/// Configure GPIOs used for GLCD
void GlcdConfig(void);

//******************************************************************************
/// De-Initialize the GLCD
void GlcdDeInit(void);

//******************************************************************************
/// Initialize the GLCD 
void GlcdInit(void);

//******************************************************************************
/// Clear display on GLCD
void GlcdClear(void);

//******************************************************************************
/// Set the Cursor of GLCD to specified position
/// @param[in]    glcdPageNum       GLCD_PAGE1, GLCD_PAGE2, GLCD_PAGE3, GLCD_PAGE4,
///                                 GLCD_PAGE5, GLCD_PAGE6, GLCD_PAGE7, GLCD_PAGE8.
/// @param[in]    glcdColumnNum     Column number (1 - 128)
void GlcdSetPage(BYTE glcdPageNum, BYTE glcdColumnNum);

//******************************************************************************
/// Write data to GLCD register
/// @param[in]    glcdData    Data to be written
void GlcdWriteData(BYTE glcdData);

//******************************************************************************
/// Send/Write command to GLCD register
/// @param[in]    glcdCmd    Command to be written, refer GLCD datasheet
void GlcdWriteCmd(BYTE glcdCmd);

//******************************************************************************
/// Send data/command byte, bit by bit
/// @param[in]    glcdDataByte    Data/Command byte
void GlcdSendDataByte(BYTE glcdDataByte);

//******************************************************************************
/// Control the backlight of the GLCD
/// @param[in]    glcdLEDStatus    TRUE  (Backlight ON)
///                                FALSE (Backlight OFF)  
void GlcdBackLight(BYTE glcdLEDStatus);

//******************************************************************************
/// Create No-Process delay
/// @param[in]    usDelay    Count for delay   
void GlcdDelay(DWORD usDelay);

//******************************************************************************
/// Display character on the GLCD
/// @param[in]    character     Character to display
///                             Example: 'A'
void GlcdDisplayChar(BYTE character);

//******************************************************************************
/// Display string on GLCD
/// @param[in]    string     String to display
///                          Example: 'TEST'
void GlcdDisplayString(BYTE *string);

#endif